"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.application.application_config_pb2
import prodvana.proto.prodvana.application.object_pb2
import prodvana.proto.prodvana.application.user_metadata_pb2
import prodvana.proto.prodvana.common_config.dangerous_action_pb2
import prodvana.proto.prodvana.insights.insights_pb2
import prodvana.proto.prodvana.metrics.metrics_pb2
import prodvana.proto.prodvana.object.meta_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListApplicationsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILED_FIELD_NUMBER: builtins.int
    detailed: builtins.bool
    """if not set, only meta without version is returned"""
    def __init__(
        self,
        *,
        detailed: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["detailed", b"detailed"]) -> None: ...

global___ListApplicationsReq = ListApplicationsReq

class ListApplicationsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATIONS_FIELD_NUMBER: builtins.int
    @property
    def applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.application.object_pb2.Application]: ...
    def __init__(
        self,
        *,
        applications: collections.abc.Iterable[prodvana.proto.prodvana.application.object_pb2.Application] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["applications", b"applications"]) -> None: ...

global___ListApplicationsResp = ListApplicationsResp

class GetApplicationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___GetApplicationReq = GetApplicationReq

class GetApplicationResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> prodvana.proto.prodvana.application.object_pb2.Application: ...
    def __init__(
        self,
        *,
        application: prodvana.proto.prodvana.application.object_pb2.Application | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___GetApplicationResp = GetApplicationResp

class ConfigureApplicationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_CONFIG_FIELD_NUMBER: builtins.int
    APPROVED_DANGEROUS_ACTION_IDS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    BASE_VERSION_FIELD_NUMBER: builtins.int
    FORCE_CREATE_NEW_VERSION_FIELD_NUMBER: builtins.int
    @property
    def application_config(self) -> prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig: ...
    @property
    def approved_dangerous_action_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    base_version: builtins.str
    """optional, if this is not a new application, this is the existing version of
    this application config that this configuration was based on.
    this can be used to avoid concurrent updates overwriting each other.
    NOTE: this will eventually be required for updates
    """
    force_create_new_version: builtins.bool
    """create new version even if there are no detected changes"""
    def __init__(
        self,
        *,
        application_config: prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig | None = ...,
        approved_dangerous_action_ids: collections.abc.Iterable[builtins.str] | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        base_version: builtins.str = ...,
        force_create_new_version: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application_config", b"application_config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_config", b"application_config", "approved_dangerous_action_ids", b"approved_dangerous_action_ids", "base_version", b"base_version", "force_create_new_version", b"force_create_new_version", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureApplicationReq = ConfigureApplicationReq

class ConfigureApplicationResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CREATED_NEW_VERSION_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    created_new_version: builtins.bool
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        created_new_version: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_new_version", b"created_new_version", "meta", b"meta"]) -> None: ...

global___ConfigureApplicationResp = ConfigureApplicationResp

class ValidateConfigureApplicationResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    DANGEROUS_ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig:
        """config as passed in by user"""
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig:
        """config with defaults applied"""
    @property
    def dangerous_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.dangerous_action_pb2.DangerousAction]: ...
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig | None = ...,
        dangerous_actions: collections.abc.Iterable[prodvana.proto.prodvana.common_config.dangerous_action_pb2.DangerousAction] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config", "dangerous_actions", b"dangerous_actions"]) -> None: ...

global___ValidateConfigureApplicationResp = ValidateConfigureApplicationResp

class GetApplicationConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    application: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "version", b"version"]) -> None: ...

global___GetApplicationConfigReq = GetApplicationConfigReq

class GetApplicationConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig:
        """config as passed in by user"""
    version: builtins.str
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig:
        """config with defaults applied"""
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig | None = ...,
        version: builtins.str = ...,
        compiled_config: prodvana.proto.prodvana.application.application_config_pb2.ApplicationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config", "version", b"version"]) -> None: ...

global___GetApplicationConfigResp = GetApplicationConfigResp

class ListApplicationConfigVersionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    application: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApplicationConfigVersionsReq = ListApplicationConfigVersionsReq

class ListApplicationConfigVersionsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class VersionMetadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VERSION_FIELD_NUMBER: builtins.int
        CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
        SOURCE_FIELD_NUMBER: builtins.int
        SOURCE_METADATA_FIELD_NUMBER: builtins.int
        version: builtins.str
        @property
        def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
        @property
        def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
        def __init__(
            self,
            *,
            version: builtins.str = ...,
            creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
            source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "source", b"source", "source_metadata", b"source_metadata", "version", b"version"]) -> None: ...

    VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListApplicationConfigVersionsResp.VersionMetadata]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[global___ListApplicationConfigVersionsResp.VersionMetadata] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "versions", b"versions"]) -> None: ...

global___ListApplicationConfigVersionsResp = ListApplicationConfigVersionsResp

class DeleteApplicationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___DeleteApplicationReq = DeleteApplicationReq

class DeleteApplicationResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteApplicationResp = DeleteApplicationResp

class GetApplicationMetricsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    application: builtins.str
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        start_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_timestamp", b"end_timestamp", "start_timestamp", b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "end_timestamp", b"end_timestamp", "start_timestamp", b"start_timestamp"]) -> None: ...

global___GetApplicationMetricsReq = GetApplicationMetricsReq

class GetApplicationMetricsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_METRICS_FIELD_NUMBER: builtins.int
    @property
    def deployment_metrics(self) -> prodvana.proto.prodvana.metrics.metrics_pb2.DeploymentMetrics: ...
    def __init__(
        self,
        *,
        deployment_metrics: prodvana.proto.prodvana.metrics.metrics_pb2.DeploymentMetrics | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_metrics", b"deployment_metrics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_metrics", b"deployment_metrics"]) -> None: ...

global___GetApplicationMetricsResp = GetApplicationMetricsResp

class GetApplicationInsightsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___GetApplicationInsightsReq = GetApplicationInsightsReq

class GetApplicationInsightsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSIGHTS_FIELD_NUMBER: builtins.int
    @property
    def insights(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.insights.insights_pb2.Insight]: ...
    def __init__(
        self,
        *,
        insights: collections.abc.Iterable[prodvana.proto.prodvana.insights.insights_pb2.Insight] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["insights", b"insights"]) -> None: ...

global___GetApplicationInsightsResp = GetApplicationInsightsResp

class SnoozeApplicationInsightReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    CLASS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "class", b"class", "duration", b"duration"]) -> None: ...

global___SnoozeApplicationInsightReq = SnoozeApplicationInsightReq

class SnoozeApplicationInsightResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SnoozeApplicationInsightResp = SnoozeApplicationInsightResp

class GetApplicationMetadataReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___GetApplicationMetadataReq = GetApplicationMetadataReq

class GetApplicationMetadataResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> prodvana.proto.prodvana.application.user_metadata_pb2.ApplicationUserMetadata:
        """metadata with no variables substitution, no modifications from parents"""
    def __init__(
        self,
        *,
        metadata: prodvana.proto.prodvana.application.user_metadata_pb2.ApplicationUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> None: ...

global___GetApplicationMetadataResp = GetApplicationMetadataResp

class SetApplicationMetadataReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    application: builtins.str
    @property
    def metadata(self) -> prodvana.proto.prodvana.application.user_metadata_pb2.ApplicationUserMetadata: ...
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        metadata: prodvana.proto.prodvana.application.user_metadata_pb2.ApplicationUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "metadata", b"metadata"]) -> None: ...

global___SetApplicationMetadataReq = SetApplicationMetadataReq

class SetApplicationMetadataResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetApplicationMetadataResp = SetApplicationMetadataResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.auth.auth_pb2
import prodvana.proto.prodvana.users.users_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    FOR_CLI_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    code: builtins.str
    redirect_url: builtins.str
    for_cli: builtins.bool
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        code: builtins.str = ...,
        redirect_url: builtins.str = ...,
        for_cli: builtins.bool = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "for_cli", b"for_cli", "prodvana_only_admin_org", b"prodvana_only_admin_org", "redirect_url", b"redirect_url"]) -> None: ...

global___GetTokenRequest = GetTokenRequest

class GetAuthUrlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_URL_FIELD_NUMBER: builtins.int
    auth_url: builtins.str
    def __init__(
        self,
        *,
        auth_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_url", b"auth_url"]) -> None: ...

global___GetAuthUrlResponse = GetAuthUrlResponse

class GetAuthUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    FOR_CLI_FIELD_NUMBER: builtins.int
    INVITATION_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    state: builtins.str
    for_cli: builtins.bool
    invitation: builtins.str
    """optional invitation id for the invite flow"""
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        state: builtins.str = ...,
        for_cli: builtins.bool = ...,
        invitation: builtins.str = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["for_cli", b"for_cli", "invitation", b"invitation", "prodvana_only_admin_org", b"prodvana_only_admin_org", "state", b"state"]) -> None: ...

global___GetAuthUrlRequest = GetAuthUrlRequest

class CliAuthReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CliAuthReq = CliAuthReq

class CliAuthResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UserPrompt(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        USER_CODE_FIELD_NUMBER: builtins.int
        VERIFICATION_URI_FIELD_NUMBER: builtins.int
        VERIFICATION_URI_COMPLETE_FIELD_NUMBER: builtins.int
        user_code: builtins.str
        verification_uri: builtins.str
        verification_uri_complete: builtins.str
        def __init__(
            self,
            *,
            user_code: builtins.str = ...,
            verification_uri: builtins.str = ...,
            verification_uri_complete: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["user_code", b"user_code", "verification_uri", b"verification_uri", "verification_uri_complete", b"verification_uri_complete"]) -> None: ...

    USER_PROMPT_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    @property
    def user_prompt(self) -> global___CliAuthResp.UserPrompt: ...
    @property
    def token(self) -> prodvana.proto.prodvana.auth.auth_pb2.AuthToken: ...
    def __init__(
        self,
        *,
        user_prompt: global___CliAuthResp.UserPrompt | None = ...,
        token: prodvana.proto.prodvana.auth.auth_pb2.AuthToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resp_oneof", b"resp_oneof", "token", b"token", "user_prompt", b"user_prompt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resp_oneof", b"resp_oneof", "token", b"token", "user_prompt", b"user_prompt"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["resp_oneof", b"resp_oneof"]) -> typing_extensions.Literal["user_prompt", "token"] | None: ...

global___CliAuthResp = CliAuthResp

class RefreshTokenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    FOR_CLI_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> prodvana.proto.prodvana.auth.auth_pb2.AuthToken: ...
    for_cli: builtins.bool
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        token: prodvana.proto.prodvana.auth.auth_pb2.AuthToken | None = ...,
        for_cli: builtins.bool = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["for_cli", b"for_cli", "prodvana_only_admin_org", b"prodvana_only_admin_org", "token", b"token"]) -> None: ...

global___RefreshTokenReq = RefreshTokenReq

class GetAuthTokenResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> prodvana.proto.prodvana.auth.auth_pb2.AuthToken: ...
    @property
    def user(self) -> prodvana.proto.prodvana.users.users_pb2.User: ...
    def __init__(
        self,
        *,
        token: prodvana.proto.prodvana.auth.auth_pb2.AuthToken | None = ...,
        user: prodvana.proto.prodvana.users.users_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token", "user", b"user"]) -> None: ...

global___GetAuthTokenResp = GetAuthTokenResp

class Empty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Empty = Empty

class LogoutReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOR_CLI_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    for_cli: builtins.bool
    redirect_url: builtins.str
    """optional redirect url after logout"""
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        for_cli: builtins.bool = ...,
        redirect_url: builtins.str = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["for_cli", b"for_cli", "prodvana_only_admin_org", b"prodvana_only_admin_org", "redirect_url", b"redirect_url"]) -> None: ...

global___LogoutReq = LogoutReq

class LogoutResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGOUT_URL_FIELD_NUMBER: builtins.int
    logout_url: builtins.str
    def __init__(
        self,
        *,
        logout_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logout_url", b"logout_url"]) -> None: ...

global___LogoutResp = LogoutResp

class CreateOrgApiTokenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRES_TIMESTAMP_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    @property
    def expires_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expires_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expires_timestamp", b"expires_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expires_timestamp", b"expires_timestamp", "name", b"name"]) -> None: ...

global___CreateOrgApiTokenReq = CreateOrgApiTokenReq

class CreateOrgApiTokenResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_TOKEN_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    api_token: builtins.str
    @property
    def info(self) -> prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo: ...
    def __init__(
        self,
        *,
        api_token: builtins.str = ...,
        info: prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token", b"api_token", "info", b"info"]) -> None: ...

global___CreateOrgApiTokenResp = CreateOrgApiTokenResp

class DeleteOrgApiTokenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteOrgApiTokenReq = DeleteOrgApiTokenReq

class DeleteOrgApiTokenResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteOrgApiTokenResp = DeleteOrgApiTokenResp

class ListOrgApiTokensReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListOrgApiTokensReq = ListOrgApiTokensReq

class ListOrgApiTokensResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKENS_FIELD_NUMBER: builtins.int
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo]: ...
    def __init__(
        self,
        *,
        tokens: collections.abc.Iterable[prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tokens", b"tokens"]) -> None: ...

global___ListOrgApiTokensResp = ListOrgApiTokensResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/deployment/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.repo import repo_pb2 as prodvana_dot_repo_dot_repo__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/deployment/object.proto\x12\x13prodvana.deployment\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1aprodvana/object/meta.proto\x1a\x18prodvana/repo/repo.proto\x1a\x17validate/validate.proto\"\xf1\x02\n\x10\x44\x65ploymentConfig\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x11\x64\x65ployment_system\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x17\n\x0frelease_channel\x18\x04 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x08 \x01(\t\x12\x12\n\nrepository\x18\x05 \x01(\t\x12\x11\n\tcommit_id\x18\x06 \x01(\t\x12\x0c\n\x04user\x18\x07 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\t \x01(\t\x12\x12\n\nservice_id\x18\n \x01(\t\x12\x1a\n\x12release_channel_id\x18\x0b \x01(\t\x12\x17\n\x0fservice_version\x18\x0c \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\r \x01(\t\x12\x12\n\nrelease_id\x18\x0e \x01(\t\"\x83\x01\n\x0f\x44\x65ploymentState\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.prodvana.deployment.DeploymentStatus\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x88\x01\n\x0e\x43ommitAnalysis\x12\x15\n\rcommits_added\x18\x01 \x01(\x03\x12\x17\n\x0f\x63ommits_removed\x18\x02 \x01(\x03\x12\x46\n\x0fimpact_analysis\x18\x03 \x01(\x0b\x32-.prodvana.deployment.ImpactAnalysisComparison\"\xa6\x01\n\x18ImpactAnalysisComparison\x12\x35\n\x16relevant_added_commits\x18\x01 \x03(\x0b\x32\x15.prodvana.repo.Commit\x12\x37\n\x18relevant_removed_commits\x18\x03 \x03(\x0b\x32\x15.prodvana.repo.Commit\x12\x1a\n\x12unanalyzed_commits\x18\x02 \x01(\x03\"\xb8\x03\n\x14\x44\x65ploymentComparison\x12)\n\x04prev\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x17\n\x0fprev_repository\x18\x02 \x01(\t\x12\x16\n\x0enew_repository\x18\x03 \x01(\t\x12\x16\n\x0eprev_commit_id\x18\x04 \x01(\t\x12\x15\n\rnew_commit_id\x18\x05 \x01(\t\x12<\n\x0f\x63ommit_analysis\x18\x0e \x01(\x0b\x32#.prodvana.deployment.CommitAnalysis\x12\x17\n\x0fprev_service_id\x18\x08 \x01(\t\x12\x1f\n\x17prev_release_channel_id\x18\t \x01(\t\x12\x1c\n\x14prev_service_version\x18\n \x01(\t\x12\x16\n\x0enew_service_id\x18\x0b \x01(\t\x12\x1e\n\x16new_release_channel_id\x18\x0c \x01(\t\x12\x1b\n\x13new_service_version\x18\r \x01(\tJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08R\x0fimpact_analysisR\rtotal_commits\"\xe2\x01\n\nDeployment\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x35\n\x06\x63onfig\x18\x02 \x01(\x0b\x32%.prodvana.deployment.DeploymentConfig\x12=\n\ncomparison\x18\x03 \x01(\x0b\x32).prodvana.deployment.DeploymentComparison\x12\x33\n\x05state\x18\x04 \x01(\x0b\x32$.prodvana.deployment.DeploymentState*[\n\x10\x44\x65ploymentStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07PREVIEW\x10\x04\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/deploymentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.deployment.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/deployment'
  _DEPLOYMENTCONFIG.fields_by_name['deployment_system']._options = None
  _DEPLOYMENTCONFIG.fields_by_name['deployment_system']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DEPLOYMENTSTATUS']._serialized_start=1655
  _globals['_DEPLOYMENTSTATUS']._serialized_end=1746
  _globals['_DEPLOYMENTCONFIG']._serialized_start=170
  _globals['_DEPLOYMENTCONFIG']._serialized_end=539
  _globals['_DEPLOYMENTSTATE']._serialized_start=542
  _globals['_DEPLOYMENTSTATE']._serialized_end=673
  _globals['_COMMITANALYSIS']._serialized_start=676
  _globals['_COMMITANALYSIS']._serialized_end=812
  _globals['_IMPACTANALYSISCOMPARISON']._serialized_start=815
  _globals['_IMPACTANALYSISCOMPARISON']._serialized_end=981
  _globals['_DEPLOYMENTCOMPARISON']._serialized_start=984
  _globals['_DEPLOYMENTCOMPARISON']._serialized_end=1424
  _globals['_DEPLOYMENT']._serialized_start=1427
  _globals['_DEPLOYMENT']._serialized_end=1653
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.volumes import volumes_pb2 as prodvana_dot_volumes_dot_volumes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/task.proto\x12\x16prodvana.common_config\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\x1a\"prodvana/common_config/retry.proto\x1a$prodvana/common_config/program.proto\x1a\x1eprodvana/volumes/volumes.proto\"\xf9\x02\n\nTaskConfig\x12@\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x38\n\x07volumes\x18\x03 \x03(\x0b\x32\x18.prodvana.volumes.VolumeB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12&\n\x03ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x0cretry_config\x18\x02 \x01(\x0b\x32#.prodvana.common_config.RetryConfig\x12\x42\n\x03k8s\x18\x05 \x01(\x0b\x32\x33.prodvana.common_config.TaskConfig.KubernetesConfigH\x00\x1a\x34\n\x10KubernetesConfig\x12 \n\x0fservice_account\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x12\n\x10runtime_specific*\x9a\x01\n\rTaskLifecycle\x12\x1a\n\x16UNKNOWN_TASK_LIFECYCLE\x10\x00\x12\x15\n\x11\x43ONVERGENCE_START\x10\x01\x12\x10\n\x0cPRE_APPROVAL\x10\x02\x12\x0c\n\x08\x41PPROVAL\x10\x03\x12\x11\n\rPOST_APPROVAL\x10\x04\x12\x0e\n\nDEPLOYMENT\x10\x05\x12\x13\n\x0fPOST_DEPLOYMENT\x10\x06\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _TASKCONFIG_KUBERNETESCONFIG.fields_by_name['service_account']._options = None
  _TASKCONFIG_KUBERNETESCONFIG.fields_by_name['service_account']._serialized_options = b'\372B\004r\002\020\001'
  _TASKCONFIG.fields_by_name['program']._options = None
  _TASKCONFIG.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TASKCONFIG.fields_by_name['volumes']._options = None
  _TASKCONFIG.fields_by_name['volumes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _globals['_TASKLIFECYCLE']._serialized_start=605
  _globals['_TASKLIFECYCLE']._serialized_end=759
  _globals['_TASKCONFIG']._serialized_start=225
  _globals['_TASKCONFIG']._serialized_end=602
  _globals['_TASKCONFIG_KUBERNETESCONFIG']._serialized_start=530
  _globals['_TASKCONFIG_KUBERNETESCONFIG']._serialized_end=582
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/model/desired_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import external_link_pb2 as prodvana_dot_common__config_dot_external__link__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2
from prodvana.proto.prodvana.protection import protection_reference_pb2 as prodvana_dot_protection_dot_protection__reference__pb2
from prodvana.proto.prodvana.runtimes.extensions import fetch_pb2 as prodvana_dot_runtimes_dot_extensions_dot_fetch__pb2
from prodvana.proto.prodvana.runtimes import debug_event_pb2 as prodvana_dot_runtimes_dot_debug__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0prodvana/desired_state/model/desired_state.proto\x12\x1cprodvana.desired_state.model\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a*prodvana/common_config/external_link.proto\x1a\'prodvana/common_config/parameters.proto\x1a$prodvana/common_config/program.proto\x1a\"prodvana/common_config/retry.proto\x1a!prodvana/common_config/task.proto\x1a#prodvana/environment/clusters.proto\x1a.prodvana/protection/protection_reference.proto\x1a(prodvana/runtimes/extensions/fetch.proto\x1a#prodvana/runtimes/debug_event.proto\"p\n\x0eProtectionLink\x12;\n\tlifecycle\x18\x03 \x01(\x0b\x32(.prodvana.protection.ProtectionLifecycle\x12\x15\n\rattachment_id\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xe3\x06\n\tCondition\x12X\n\x07rc_cond\x18\x01 \x01(\x0b\x32\x45.prodvana.desired_state.model.Condition.ReleaseChannelStableConditionH\x00\x12Q\n\x0fmanual_approval\x18\x02 \x01(\x0b\x32\x36.prodvana.desired_state.model.Condition.ManualApprovalH\x00\x12\\\n\x0b\x63ustom_task\x18\x03 \x01(\x0b\x32\x45.prodvana.desired_state.model.Condition.CustomTaskSuccessfulConditionH\x00\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x1a\xe2\x01\n\x1dReleaseChannelStableCondition\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x12\n\nservice_id\x18\x03 \x01(\t\x12\x17\n\x0frelease_channel\x18\x04 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x05 \x01(\t\x12\x17\n\x0fservice_version\x18\x06 \x01(\t\x12\x39\n1internal_only_satisfied_in_replaced_desired_state\x18\x07 \x01(\x08\x1a\x34\n\x0eManualApproval\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x1a\x88\x02\n\x1d\x43ustomTaskSuccessfulCondition\x12\x18\n\x10\x63ustom_task_name\x18\x01 \x01(\t\x12\x66\n\nprotection\x18\x02 \x01(\x0b\x32P.prodvana.desired_state.model.Condition.CustomTaskSuccessfulCondition.ProtectionH\x00\x1a[\n\nProtection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\ttask_type\x18\x03 \x01(\x0e\x32,.prodvana.desired_state.model.CustomTaskTypeB\x08\n\x06sourceB\x0b\n\tcondition\"\xa0\x01\n\x11\x44\x65liveryExtension\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x38\n\tlifecycle\x18\x02 \x01(\x0e\x32%.prodvana.common_config.TaskLifecycle\x12<\n\nreferences\x18\x03 \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\"j\n\x1eProtectionAttachmentDefinition\x12\x15\n\rprotection_id\x18\x01 \x01(\t\x12\x15\n\rattachment_id\x18\x02 \x01(\t\x12\x1a\n\x12protection_version\x18\x03 \x01(\t\"L\n\nIdentifier\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".prodvana.desired_state.model.Type\x12\x0c\n\x04name\x18\x02 \x01(\t\"$\n\x10\x43oncurrencyLimit\x12\x10\n\x08limit_id\x18\x01 \x01(\t\"\x95\x06\n\x08Metadata\x12>\n\rpreconditions\x18\x01 \x03(\x0b\x32\'.prodvana.desired_state.model.Condition\x12;\n\ninvariants\x18\x02 \x03(\x0b\x32\'.prodvana.desired_state.model.Condition\x12\x36\n\x04self\x18\x03 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x05 \x01(\t\x12\x12\n\nrelease_id\x18\x0e \x01(\t\x12\x46\n\x10protection_links\x18\x06 \x03(\x0b\x32,.prodvana.desired_state.model.ProtectionLink\x12L\n\x13\x64\x65livery_extensions\x18\x08 \x03(\x0b\x32/.prodvana.desired_state.model.DeliveryExtension\x12h\n\"convergence_protection_attachments\x18\r \x03(\x0b\x32<.prodvana.desired_state.model.ProtectionAttachmentDefinition\x12J\n\x12\x63oncurrency_limits\x18\x0f \x03(\x0b\x32..prodvana.desired_state.model.ConcurrencyLimit\x12\"\n\x1atarget_state_set_by_parent\x18\t \x01(\x08\x12%\n\x1drequire_approval_before_apply\x18\n \x01(\x08\x12 \n\x18\x61pplies_in_observer_mode\x18\x0b \x01(\x08\x12;\n\x18\x63onvergence_grace_period\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationJ\x04\x08\x07\x10\x08R\x0bprotections\"\xad\x01\n\x11StatusExplanation\x12\x39\n\x07subject\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12:\n\x06reason\x18\x02 \x01(\x0e\x32*.prodvana.desired_state.model.StatusReason\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x10\n\x08messages\x18\x04 \x03(\t\"\x8b\x01\n\x11\x41\x63tionExplanation\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x0b\x61\x63tion_type\x18\x02 \x01(\x0e\x32(.prodvana.desired_state.model.ActionType\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xde\x01\n\x07Version\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12\x1a\n\x12\x61vailable_replicas\x18\x08 \x01(\x05\x12\x32\n\x0epush_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x17\n\x0ftarget_replicas\x18\x06 \x01(\x05\x12\r\n\x05\x64irty\x18\t \x01(\x08J\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08R\tunhealthyR\x11unhealthy_reasons\"\xe8\x03\n\x14ServiceInstanceState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x13\n\x0b\x61pplication\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x17\n\x0frelease_channel\x18\x04 \x01(\t\x12\x12\n\nservice_id\x18\x08 \x01(\t\x12\x1a\n\x12release_channel_id\x18\t \x01(\t\x12\x37\n\x08versions\x18\x05 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x41\n\x10rollback_version\x18\x06 \x01(\x0b\x32%.prodvana.desired_state.model.VersionH\x00\x12\"\n\x18\x63ompute_rollback_version\x18\x0b \x01(\x08H\x00\x12\x10\n\x08rollback\x18\x07 \x01(\x08\x12=\n\x08\x64\x65livery\x18\n \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\x12$\n\x1c\x64\x65ployment_owned_by_children\x18\x0c \x01(\x08\x42\x14\n\x12\x61utorollback_oneof\"\xd5\x03\n\x0cServiceState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x13\n\x0b\x61pplication\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x12\n\nservice_id\x18\x05 \x01(\t\x12L\n\x10release_channels\x18\x06 \x03(\x0b\x32\x32.prodvana.desired_state.model.ServiceInstanceState\x12\x43\n\x0c\x63ustom_tasks\x18\x07 \x03(\x0b\x32-.prodvana.desired_state.model.CustomTaskState\x12Q\n\x13\x64\x65livery_extensions\x18\t \x03(\x0b\x32\x34.prodvana.desired_state.model.DeliveryExtensionState\x12\x63\n\x1frelease_channel_label_selectors\x18\n \x03(\x0b\x32:.prodvana.desired_state.model.ServiceInstanceLabelSelectorJ\x04\x08\x04\x10\x05J\x04\x08\x08\x10\t\"\xc5\x02\n\x1cServiceInstanceLabelSelector\x12\"\n\x18release_channel_selector\x18\x01 \x01(\tH\x00\x12\r\n\x03\x61ll\x18\x02 \x01(\x08H\x00\x12\x37\n\x08versions\x18\x03 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x41\n\x10rollback_version\x18\x04 \x01(\x0b\x32%.prodvana.desired_state.model.VersionH\x01\x12\"\n\x18\x63ompute_rollback_version\x18\x05 \x01(\x08H\x01\x12%\n\x1dmaterialized_release_channels\x18\x06 \x03(\tB\x15\n\x0eselector_oneof\x12\x03\xf8\x42\x01\x42\x14\n\x12\x61utorollback_oneof\"\xa5\x02\n\x11ServiceGroupState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12<\n\x08services\x18\x02 \x03(\x0b\x32*.prodvana.desired_state.model.ServiceState\x12\x43\n\x0c\x63ustom_tasks\x18\x03 \x03(\x0b\x32-.prodvana.desired_state.model.CustomTaskState\x12Q\n\x13\x64\x65livery_extensions\x18\x05 \x03(\x0b\x32\x34.prodvana.desired_state.model.DeliveryExtensionStateJ\x04\x08\x04\x10\x05\"\xa8\x02\n\x13\x43\x61naryProgressState\x12H\n\x06status\x18\x01 \x01(\x0e\x32\x38.prodvana.desired_state.model.CanaryProgressState.Status\x12 \n\rcanary_weight\x18\x02 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x64(\x00\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x15pause_start_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"=\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\r\n\tCOMPLETED\x10\x03\"\xdb\x01\n\x16\x42lueGreenProgressState\x12K\n\x06status\x18\x01 \x01(\x0e\x32;.prodvana.desired_state.model.BlueGreenProgressState.Status\"t\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nSCALING_UP\x10\x02\x12\x12\n\x0ePAUSED_PREVIEW\x10\x03\x12\x10\n\x0cSCALING_DOWN\x10\x04\x12\r\n\tCOMPLETED\x10\x05\x12\x0b\n\x07\x41\x42ORTED\x10\x06\"\xe7\x03\n\rDeliveryState\x12\x18\n\x10\x64\x65sired_state_id\x18\x0c \x01(\t\x12\x42\n\x06status\x18\x08 \x01(\x0e\x32\x32.prodvana.desired_state.model.DeliveryState.Status\x12\x0f\n\x07message\x18\x06 \x01(\t\x12J\n\x0f\x63\x61nary_progress\x18\x0b \x03(\x0b\x32\x31.prodvana.desired_state.model.CanaryProgressState\x12\x11\n\tfirst_run\x18\r \x01(\x08\x12\x12\n\ngeneration\x18\x0e \x01(\t\x12Q\n\x13\x62lue_green_progress\x18\x0f \x01(\x0b\x32\x34.prodvana.desired_state.model.BlueGreenProgressState\"q\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x16\n\x12STATUS_PROGRESSING\x10\x01\x12\x11\n\rSTATUS_PAUSED\x10\x02\x12\x12\n\x0eSTATUS_HEALTHY\x10\x03\x12\x14\n\x10STATUS_UNHEALTHY\x10\x04J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\xd5\x03\n\x0c\x46\x65tchDetails\x12\x35\n\x11started_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13\x63ompleted_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12\x66\x65tch_plan_blob_id\x18\x03 \x01(\t\x12&\n\x1e\x66\x65tch_plan_explanation_blob_id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12L\n\x0c\x66\x65tch_status\x18\x06 \x01(\x0e\x32\x36.prodvana.desired_state.model.FetchDetails.FetchStatus\x12 \n\x18\x66\x65tcher_desired_state_id\x18\x07 \x01(\t\x12\x0f\n\x07message\x18\x08 \x01(\t\x12;\n\nfetch_mode\x18\t \x01(\x0e\x32\'.prodvana.runtimes.extensions.FetchMode\"B\n\x0b\x46\x65tchStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x44RIFTED\x10\x01\x12\r\n\tCONVERGED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\"\x8f\x03\n\x1bRuntimeExtensionFetchOutput\x12\x41\n\rongoing_fetch\x18\x08 \x01(\x0b\x32*.prodvana.desired_state.model.FetchDetails\x12I\n\x15last_successful_fetch\x18\t \x01(\x0b\x32*.prodvana.desired_state.model.FetchDetails\x12\x45\n\x11last_failed_fetch\x18\n \x01(\x0b\x32*.prodvana.desired_state.model.FetchDetailsJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08R\x12\x66\x65tch_plan_blob_idR\x1e\x66\x65tch_plan_explanation_blob_idR\x07versionR\x0c\x66\x65tch_statusR\x11started_timestampR\x13\x63ompleted_timestamp\"E\n$RuntimeExtensionGetInfoOutputContent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x62lob_id\x18\x02 \x01(\t\"\x96\x03\n\x1eRuntimeExtensionGetInfoDetails\x12\x16\n\x0esystem_message\x18\x01 \x01(\t\x12T\n\x08\x63ontents\x18\x02 \x03(\x0b\x32\x42.prodvana.desired_state.model.RuntimeExtensionGetInfoOutputContent\x12S\n\x06status\x18\x03 \x01(\x0e\x32\x43.prodvana.desired_state.model.RuntimeExtensionGetInfoDetails.Status\x12\x35\n\x11started_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13\x63ompleted_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x06 \x01(\t\"0\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tCONVERGED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"w\n\x1dRuntimeExtensionGetInfoOutput\x12V\n\x10get_info_details\x18\x01 \x01(\x0b\x32<.prodvana.desired_state.model.RuntimeExtensionGetInfoDetails\"\xe6\x02\n\x0c\x41pplyDetails\x12\x35\n\x11started_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13\x63ompleted_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x03 \x01(\t\x12L\n\x0c\x61pply_status\x18\x04 \x01(\x0e\x32\x36.prodvana.desired_state.model.ApplyDetails.ApplyStatus\x12\x41\n\rfetch_details\x18\x05 \x01(\x0b\x32*.prodvana.desired_state.model.FetchDetails\"D\n\x0b\x41pplyStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tCONVERGED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\r\n\tRETRYABLE\x10\x03\"\xa0\x01\n\x1bRuntimeExtensionApplyOutput\x12\x41\n\rongoing_apply\x18\x01 \x01(\x0b\x32*.prodvana.desired_state.model.ApplyDetails\x12>\n\nlast_apply\x18\x02 \x01(\x0b\x32*.prodvana.desired_state.model.ApplyDetails\"\x85\x14\n\rRuntimeObject\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x15\n\rgenerate_name\x18\x18 \x01(\t\x12\x37\n\x08versions\x18\x05 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12<\n\rfetch_version\x18\x1d \x01(\x0b\x32%.prodvana.desired_state.model.Version\x12\x42\n\x06status\x18\x06 \x01(\x0e\x32\x32.prodvana.desired_state.model.RuntimeObject.Status\x12?\n\x10rollback_version\x18\x07 \x01(\x0b\x32%.prodvana.desired_state.model.Version\x12=\n\x08\x64\x65livery\x18\x08 \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\x12\x18\n\x10version_agnostic\x18\n \x01(\x08\x12\"\n\x1a\x64\x65sired_version_dirty_only\x18\x14 \x01(\x08\x12\x0f\n\x07message\x18\x0c \x01(\t\x12\x33\n\x0c\x64\x65\x62ug_events\x18\x1f \x03(\x0b\x32\x1d.prodvana.runtimes.DebugEvent\x12W\n\x11runtime_extension\x18\r \x01(\x0b\x32<.prodvana.desired_state.model.RuntimeObject.RuntimeExtension\x12+\n\x08interval\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15steady_state_interval\x18\x1a \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x17\n\x0foutput_blob_ids\x18\x12 \x03(\t\x12\x12\n\nexit_codes\x18\x13 \x03(\x05\x12%\n\x1drequire_approval_before_apply\x18\x15 \x01(\x08\x12\x12\n\nraw_config\x18\x17 \x01(\t\x12W\n\x11management_status\x18\x19 \x01(\x0e\x32<.prodvana.desired_state.model.RuntimeObject.ManagementStatus\x12\x46\n\x17last_completed_task_run\x18\x1b \x01(\x0b\x32%.prodvana.desired_state.model.TaskRun\x12<\n\x0e\x65xternal_links\x18\x1c \x03(\x0b\x32$.prodvana.common_config.ExternalLink\x12\x46\n\x10\x65xternal_objects\x18\x1e \x03(\x0b\x32,.prodvana.runtimes.extensions.ExternalObject\x12\x10\n\x08rollback\x18  \x01(\x08\x1a\x8f\t\n\x10RuntimeExtension\x12=\n\x05\x61pply\x18\x03 \x01(\x0b\x32..prodvana.environment.CompiledExtensionCommand\x12=\n\x05\x66\x65tch\x18\x01 \x01(\x0b\x32..prodvana.environment.CompiledExtensionCommand\x12@\n\x08get_info\x18\x11 \x01(\x0b\x32..prodvana.environment.CompiledExtensionCommand\x12\x31\n\x0e\x66\x65tch_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12>\n\x1b\x66\x65tch_steady_state_interval\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11get_info_interval\x18\x13 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x06 \x01(\t\x12?\n\nparameters\x18\x07 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinition\x12@\n\x10parameter_values\x18\x08 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x12\x31\n\x04type\x18\t \x01(\x0e\x32#.prodvana.environment.ExtensionType\x12O\n\x0c\x66\x65tch_output\x18\n \x01(\x0b\x32\x39.prodvana.desired_state.model.RuntimeExtensionFetchOutput\x12T\n\x0fget_info_output\x18\x10 \x01(\x0b\x32;.prodvana.desired_state.model.RuntimeExtensionGetInfoOutput\x12O\n\x0c\x61pply_output\x18\x0c \x01(\x0b\x32\x39.prodvana.desired_state.model.RuntimeExtensionApplyOutput\x12=\n\x12\x66\x65tch_retry_policy\x18\r \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12=\n\x12\x61pply_retry_policy\x18\x0e \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12@\n\x15get_info_retry_policy\x18\x12 \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12\"\n\x1a\x61pply_retryable_exit_codes\x18\x0f \x03(\x05\x12;\n\nfetch_mode\x18\x14 \x01(\x0e\x32\'.prodvana.runtimes.extensions.FetchModeJ\x04\x08\x05\x10\x06R\rfetch_timeout\"0\n\x06Status\x12\x0b\n\x07PENDING\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"2\n\x10ManagementStatus\x12\x0f\n\x0bPVN_MANAGED\x10\x00\x12\r\n\tUNMANAGED\x10\x01J\x04\x08\t\x10\nJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0e\x10\x0fJ\x04\x08\x10\x10\x11J\x04\x08\x11\x10\x12J\x04\x08\x16\x10\x17R\x0eunhealthy_podsR\nstate_hashR\x10missing_approvalR\x07timeout\"O\n\x0e\x43onditionState\x12=\n\x06status\x18\x01 \x01(\x0e\x32-.prodvana.desired_state.model.ConditionStatus\"\x1d\n\nApplyError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xe1\x02\n\x10NotificationInfo\x12\x15\n\rfailure_count\x18\x01 \x01(\x05\x12\x37\n\x13most_recent_failure\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12L\n\x1aruntime_fetch_invoke_error\x18\x0b \x01(\x0b\x32(.prodvana.desired_state.model.ApplyError\x12L\n\x1aruntime_apply_invoke_error\x18\x0c \x01(\x0b\x32(.prodvana.desired_state.model.ApplyError\x12\x61\n!concurrency_limit_exceeded_errors\x18\r \x03(\x0b\x32\x36.prodvana.desired_state.model.ConcurrencyLimitExceeded\"\xc0\x05\n\x0c\x43ontrolState\x12\x10\n\x08rollback\x18\x01 \x01(\x08\x12I\n\x13precondition_states\x18\x02 \x03(\x0b\x32,.prodvana.desired_state.model.ConditionState\x12\x46\n\x10invariant_states\x18\x03 \x03(\x0b\x32,.prodvana.desired_state.model.ConditionState\x12\x0e\n\x06paused\x18\x04 \x01(\x08\x12L\n\x13status_explanations\x18\x05 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12K\n\x12\x61\x63tion_explanation\x18\x06 \x01(\x0b\x32/.prodvana.desired_state.model.ActionExplanation\x12:\n\x16last_fetched_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_applied_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x10missing_approval\x18\t \x01(\x0b\x32-.prodvana.desired_state.model.MissingApproval\x12\x15\n\robserver_mode\x18\n \x01(\x08\x12=\n\x0b\x61pply_error\x18\x0b \x01(\x0b\x32(.prodvana.desired_state.model.ApplyError\x12I\n\x11notification_info\x18\x0c \x01(\x0b\x32..prodvana.desired_state.model.NotificationInfo\"\xb3\x01\n\x13ManualApprovalState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x42\n\x06status\x18\x02 \x01(\x0e\x32\x32.prodvana.desired_state.model.ManualApprovalStatus\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\xc1\x05\n\x05State\x12=\n\x07service\x18\x01 \x01(\x0b\x32*.prodvana.desired_state.model.ServiceStateH\x00\x12N\n\x10service_instance\x18\x02 \x01(\x0b\x32\x32.prodvana.desired_state.model.ServiceInstanceStateH\x00\x12H\n\rservice_group\x18\x03 \x01(\x0b\x32/.prodvana.desired_state.model.ServiceGroupStateH\x00\x12\x45\n\x0eruntime_object\x18\x04 \x01(\x0b\x32+.prodvana.desired_state.model.RuntimeObjectH\x00\x12L\n\x0fmanual_approval\x18\x05 \x01(\x0b\x32\x31.prodvana.desired_state.model.ManualApprovalStateH\x00\x12\x44\n\x0b\x63ustom_task\x18\x06 \x01(\x0b\x32-.prodvana.desired_state.model.CustomTaskStateH\x00\x12S\n\x15protection_attachment\x18\x07 \x01(\x0b\x32\x32.prodvana.desired_state.model.ProtectionAttachmentH\x00\x12L\n\x0fprotection_link\x18\x08 \x01(\x0b\x32\x31.prodvana.desired_state.model.ProtectionLinkStateH\x00\x12R\n\x12\x64\x65livery_extension\x18\t \x01(\x0b\x32\x34.prodvana.desired_state.model.DeliveryExtensionStateH\x00\x42\r\n\x0bstate_oneof\"\x82\x01\n\x0b\x41nnotations\x12I\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x34.prodvana.desired_state.model.Annotations.Annotation\x1a(\n\nAnnotation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xae\x01\n\x18\x43ustomTaskExecutionState\x12>\n\x06status\x18\x01 \x01(\x0e\x32..prodvana.desired_state.model.CustomTaskStatus\x12\x10\n\x08\x61ttempts\x18\x02 \x01(\x03\x12@\n\x1clatest_attempt_end_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xce\x03\n\x0f\x43ustomTaskState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x61pplication\x18\x04 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x05 \x01(\t\x12\x17\n\x0frelease_channel\x18\x06 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x07 \x01(\t\x12@\n\x07program\x18\t \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12J\n\ntask_state\x18\x0c \x01(\x0b\x32\x36.prodvana.desired_state.model.CustomTaskExecutionState\x12\x39\n\x0cretry_config\x18\r \x01(\x0b\x32#.prodvana.common_config.RetryConfig\x12\x13\n\x0bservice_ids\x18\x0e \x03(\tJ\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"\xcf\x05\n\x13ProtectionLinkState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x17\n\x0f\x61ttachment_name\x18\x08 \x01(\t\x12I\n\x1blast_seen_attachment_status\x18\t \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12=\n\x06status\x18\x02 \x01(\x0e\x32-.prodvana.desired_state.model.ConditionStatus\x12:\n\x04link\x18\x03 \x01(\x0b\x32,.prodvana.desired_state.model.ProtectionLink\x12\x35\n\x11started_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11stopped_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\x0estopped_reason\x18\x06 \x01(\x0e\x32<.prodvana.desired_state.model.ProtectionLinkState.StopReason\x12;\n\x17\x66irst_success_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa1\x01\n\nStopReason\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x17\n\x13LIFECYCLE_COMPLETED\x10\x01\x12\x12\n\x0eSUCCEEDED_ONCE\x10\x02\x12\x1a\n\x16SUCCEEDED_FOR_DURATION\x10\x03\x12\r\n\tTIMED_OUT\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0b\n\x07\x44\x45LETED\x10\x06\x12\x15\n\x11MANUALLY_BYPASSED\x10\x07\"\x89\x04\n\x14ProtectionAttachment\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x37\n\x08versions\x18\x02 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x46\n\x17last_completed_versions\x18\x05 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12<\n\x18last_completed_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x15last_completed_status\x18\x07 \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12[\n\"last_completed_status_explanations\x18\x08 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12&\n\x1elast_completed_applied_version\x18\t \x01(\t\x12\x15\n\rprotection_id\x18\x03 \x01(\t\x12\x15\n\rattachment_id\x18\x04 \x01(\t\"\xe2\x04\n\x16\x44\x65liveryExtensionState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x37\n\x08versions\x18\x02 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x14\n\x0c\x65xtension_id\x18\x03 \x01(\t\x12\x1d\n\x15\x65xtension_instance_id\x18\n \x01(\t\x12\x38\n\tlifecycle\x18\x0b \x01(\x0e\x32%.prodvana.common_config.TaskLifecycle\x12<\n\x18last_completed_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x15last_completed_status\x18\x07 \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12[\n\"last_completed_status_explanations\x18\x08 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12&\n\x1elast_completed_applied_version\x18\t \x01(\t\x12\x10\n\x08\x61ttempts\x18\x0e \x01(\x05\x12<\n\nreferences\x18\x0c \x03(\x0b\x32(.prodvana.desired_state.model.IdentifierJ\x04\x08\r\x10\x0eR\x06status\"\xac\x04\n\x06Signal\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.prodvana.desired_state.model.SignalType\x12Z\n\x12\x64\x65livery_promotion\x18\x02 \x01(\x0b\x32<.prodvana.desired_state.model.Signal.DeliveryPromotionConfigH\x00\x12R\n\x11protection_bypass\x18\x03 \x01(\x0b\x32\x35.prodvana.desired_state.model.Signal.ProtectionBypassH\x00\x12\x63\n\x1aruntime_extension_approval\x18\x04 \x01(\x0b\x32=.prodvana.desired_state.model.Signal.RuntimeExtensionApprovalH\x00\x1a\x46\n\x17\x44\x65liveryPromotionConfig\x12\r\n\x05stage\x18\x01 \x01(\x03\x12\x0c\n\x04\x66ull\x18\x02 \x01(\x08\x12\x0e\n\x06reject\x18\x03 \x01(\x08\x1a\x12\n\x10ProtectionBypass\x1ao\n\x18RuntimeExtensionApproval\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reject\x18\x02 \x01(\x08\x12\x14\n\x0cplan_blob_id\x18\x03 \x01(\tB\x08\n\x06\x63onfig\"?\n\x08\x44\x65\x62ugLog\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03log\x18\x02 \x01(\t\"\x85\x01\n\x18RuntimeExtensionMetadata\x12I\n\x06output\x18\x01 \x01(\x0b\x32\x39.prodvana.desired_state.model.RuntimeExtensionFetchOutput\x12\x1e\n\x16\x61pply_desired_state_id\x18\x02 \x01(\t\"u\n\x14ManualApprovalConfig\x12S\n\x11runtime_extension\x18\x01 \x01(\x0b\x32\x36.prodvana.desired_state.model.RuntimeExtensionMetadataH\x00\x42\x08\n\x06\x63onfig\"\xdd\x01\n\x0fMissingApproval\x12\x18\n\x10\x64\x65sired_state_id\x18\x01 \x01(\t\x12=\n\x0bsignal_type\x18\x02 \x01(\x0e\x32(.prodvana.desired_state.model.SignalType\x12\r\n\x05topic\x18\x03 \x01(\t\x12Q\n\x11runtime_extension\x18\x04 \x01(\x0b\x32\x36.prodvana.desired_state.model.RuntimeExtensionMetadata\x12\x0f\n\x07\x63urrent\x18\x05 \x01(\x08\"\xb2\x01\n\x18\x43oncurrencyLimitExceeded\x12;\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12>\n\x0c\x62locking_ids\x18\x02 \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x19\n\x11limit_description\x18\x03 \x01(\t\"\xec\x03\n\x19\x41pplyConditionUnsatisfied\x12k\n\x10missing_approval\x18\x01 \x01(\x0b\x32O.prodvana.desired_state.model.ApplyConditionUnsatisfied.InternalMissingApprovalH\x00\x12\\\n\x1a\x63oncurrency_limit_exceeded\x18\x02 \x01(\x0b\x32\x36.prodvana.desired_state.model.ConcurrencyLimitExceededH\x00\x1a\xf9\x01\n\x17InternalMissingApproval\x12\x18\n\x10\x64\x65sired_state_id\x18\x01 \x01(\t\x12=\n\x0bsignal_type\x18\x02 \x01(\x0e\x32(.prodvana.desired_state.model.SignalType\x12\r\n\x05topic\x18\x03 \x01(\t\x12Q\n\x11runtime_extension\x18\x04 \x01(\x0b\x32\x36.prodvana.desired_state.model.RuntimeExtensionMetadata\x12#\n\x1bgenerator_desired_state_ids\x18\x05 \x03(\tB\x08\n\x06reason\"T\n\x15\x46\x65tchTaskStartDetails\x12;\n\nfetch_mode\x18\x01 \x01(\x0e\x32\'.prodvana.runtimes.extensions.FetchMode\"6\n\x10\x43oncurrencyLease\x12\x10\n\x08limit_id\x18\x01 \x01(\t\x12\x10\n\x08lease_id\x18\x02 \x01(\t\"\x90\x07\n\x07TaskRun\x12:\n\x06status\x18\x01 \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12L\n\x13status_explanations\x18\x02 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12\x0f\n\x07version\x18\x03 \x01(\t\x12<\n\rseen_versions\x18\x04 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x35\n\x11\x63reated_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11started_timestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13\x63ompleted_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15started_by_process_id\x18\x10 \x01(\t\x12\x17\n\x0foutput_blob_ids\x18\x07 \x03(\t\x12\x12\n\nexit_codes\x18\x08 \x03(\x05\x12?\n\rtask_entities\x18\t \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x1c\n\x14retryable_exit_codes\x18\x0b \x03(\x05\x12\x11\n\tretryable\x18\x0c \x01(\x08\x12:\n\x05phase\x18\r \x01(\x0e\x32+.prodvana.desired_state.model.TaskRun.Phase\x12\x41\n\rfetch_details\x18\n \x01(\x0b\x32*.prodvana.desired_state.model.FetchDetails\x12U\n\x18\x66\x65tch_task_start_details\x18\x0e \x01(\x0b\x32\x33.prodvana.desired_state.model.FetchTaskStartDetails\x12J\n\x12\x63oncurrency_leases\x18\x11 \x03(\x0b\x32..prodvana.desired_state.model.ConcurrencyLease\"%\n\x05Phase\x12\x0b\n\x07RUNNING\x10\x00\x12\x0f\n\x0bNOT_STARTED\x10\x01\"\xd8\x01\n\x11TaskEntityContext\x12\x41\n\x12last_completed_run\x18\x01 \x01(\x0b\x32%.prodvana.desired_state.model.TaskRun\x12\x37\n\x08last_run\x18\x02 \x01(\x0b\x32%.prodvana.desired_state.model.TaskRun\x12\x11\n\tis_active\x18\x03 \x01(\x08J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x10missing_approvalR\x16is_not_in_grace_period\"Y\n\x17SetDesiredStateMetadata\x12\x10\n\x08rollback\x18\x01 \x01(\x08\x12,\n$bypass_preconditions_and_protections\x18\x02 \x01(\x08*\xcb\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVICE\x10\x01\x12\x14\n\x10SERVICE_INSTANCE\x10\x02\x12\x11\n\rSERVICE_GROUP\x10\x03\x12\x12\n\x0eRUNTIME_OBJECT\x10\x04\x12\x13\n\x0fMANUAL_APPROVAL\x10\x05\x12\x0f\n\x0b\x43USTOM_TASK\x10\x06\x12\x19\n\x15PROTECTION_ATTACHMENT\x10\x07\x12\x13\n\x0fPROTECTION_LINK\x10\x08\x12\x16\n\x12\x44\x45LIVERY_EXTENSION\x10\t*\x9a\x01\n\x0e\x43ustomTaskType\x12\x1c\n\x18\x43USTOM_TASK_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11PRE_APPROVAL_TASK\x10\x01\x12\x0c\n\x08\x41PPROVAL\x10\x02\x12\x16\n\x12POST_APPROVAL_TASK\x10\x03\x12\x13\n\x0f\x44\x45PLOYMENT_TASK\x10\x04\x12\x18\n\x14POST_DEPLOYMENT_TASK\x10\x05*\x9c\x02\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0e\n\nCONVERGING\x10\x01\x12\r\n\tCONVERGED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x10\n\x0cROLLING_BACK\x10\x04\x12\x0f\n\x0bROLLED_BACK\x10\x05\x12\x13\n\x0f\x46\x41ILED_ROLLBACK\x10\x0c\x12\n\n\x06PAUSED\x10\x06\x12\x10\n\x0c\x43HILD_PAUSED\x10\x07\x12\x19\n\x15WAITING_PRECONDITIONS\x10\x08\x12\x0c\n\x08REPLACED\x10\t\x12\x1b\n\x17WAITING_MANUAL_APPROVAL\x10\n\x12\x0b\n\x07\x44\x45LETED\x10\x0b\x12\x0b\n\x07PREVIEW\x10\r\x12\x1d\n\x19PENDING_SET_DESIRED_STATE\x10\x0e*o\n\x0cSimpleStatus\x12\x0e\n\nSS_UNKNOWN\x10\x00\x12\x11\n\rSS_CONVERGING\x10\x01\x12\x10\n\x0cSS_CONVERGED\x10\x02\x12\r\n\tSS_FAILED\x10\x03\x12\x1b\n\x17SS_WAITING_FOR_APPROVAL\x10\x04*\xff\x01\n\x0cStatusReason\x12\x12\n\x0eREASON_UNKNOWN\x10\x00\x12\x14\n\x10NO_CURRENT_STATE\x10\x01\x12\x10\n\x0c\x41PPLY_FAILED\x10\x02\x12\x12\n\x0eUNHEALTHY_PODS\x10\x03\x12\x11\n\rUPDATING_PODS\x10\x04\x12\x14\n\x10VERSION_MISMATCH\x10\x05\x12\x19\n\x15RUNTIME_OBJECT_FAILED\x10\x06\x12\x18\n\x14PRECONDITIONS_FAILED\x10\x07\x12\x1c\n\x18MANUAL_APPROVAL_REJECTED\x10\x08\x12\x10\n\x0cSTUCK_ENTITY\x10\t\x12\x11\n\rVERSION_DIRTY\x10\n*r\n\nActionType\x12\x17\n\x13\x41\x43TION_TYPE_UNKNOWN\x10\x00\x12\x18\n\x14\x41\x43TION_TYPE_APPLYING\x10\x01\x12\x17\n\x13\x41\x43TION_TYPE_APPLIED\x10\x02\x12\x18\n\x14\x41\x43TION_TYPE_COMPLETE\x10\x03*\x96\x01\n\x0f\x43onditionStatus\x12\x1c\n\x18\x43ONDITION_UNKNOWN_STATUS\x10\x00\x12\x15\n\x11\x43ONDITION_PENDING\x10\x01\x12\x17\n\x13\x43ONDITION_SATISFIED\x10\x02\x12\x1f\n\x1b\x43ONDITION_MANUALLY_BYPASSED\x10\x03\x12\x14\n\x10\x43ONDITION_FAILED\x10\x04*?\n\x14ManualApprovalStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41PPROVED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02*\x85\x01\n\x10\x43ustomTaskStatus\x12\x17\n\x13\x43USTOM_TASK_PENDING\x10\x00\x12\x1a\n\x16\x43USTOM_TASK_SUCCESSFUL\x10\x01\x12!\n\x1d\x43USTOM_TASK_RETRIES_EXHAUSTED\x10\x02\x12\x19\n\x15\x43USTOM_TASK_TIMED_OUT\x10\x03*\x8b\x01\n\nSignalType\x12\x12\n\x0eSIGNAL_UNKNOWN\x10\x00\x12\x16\n\x12\x44\x45LIVERY_PROMOTION\x10\x01\x12\x15\n\x11PROTECTION_BYPASS\x10\x02\x12\x1e\n\x1aRUNTIME_EXTENSION_APPROVAL\x10\x03\x12\x1a\n\x16SIGNAL_MANUAL_APPROVAL\x10\x04\x42XZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.model.desired_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/model'
  _SERVICEINSTANCELABELSELECTOR.oneofs_by_name['selector_oneof']._options = None
  _SERVICEINSTANCELABELSELECTOR.oneofs_by_name['selector_oneof']._serialized_options = b'\370B\001'
  _CANARYPROGRESSSTATE.fields_by_name['canary_weight']._options = None
  _CANARYPROGRESSSTATE.fields_by_name['canary_weight']._serialized_options = b'\372B\006\032\004\030d(\000'
  _CUSTOMTASKSTATE.fields_by_name['name']._options = None
  _CUSTOMTASKSTATE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CUSTOMTASKSTATE.fields_by_name['description']._options = None
  _CUSTOMTASKSTATE.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _CUSTOMTASKSTATE.fields_by_name['program']._options = None
  _CUSTOMTASKSTATE.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_TYPE']._serialized_start=18247
  _globals['_TYPE']._serialized_end=18450
  _globals['_CUSTOMTASKTYPE']._serialized_start=18453
  _globals['_CUSTOMTASKTYPE']._serialized_end=18607
  _globals['_STATUS']._serialized_start=18610
  _globals['_STATUS']._serialized_end=18894
  _globals['_SIMPLESTATUS']._serialized_start=18896
  _globals['_SIMPLESTATUS']._serialized_end=19007
  _globals['_STATUSREASON']._serialized_start=19010
  _globals['_STATUSREASON']._serialized_end=19265
  _globals['_ACTIONTYPE']._serialized_start=19267
  _globals['_ACTIONTYPE']._serialized_end=19381
  _globals['_CONDITIONSTATUS']._serialized_start=19384
  _globals['_CONDITIONSTATUS']._serialized_end=19534
  _globals['_MANUALAPPROVALSTATUS']._serialized_start=19536
  _globals['_MANUALAPPROVALSTATUS']._serialized_end=19599
  _globals['_CUSTOMTASKSTATUS']._serialized_start=19602
  _globals['_CUSTOMTASKSTATUS']._serialized_end=19735
  _globals['_SIGNALTYPE']._serialized_start=19738
  _globals['_SIGNALTYPE']._serialized_end=19877
  _globals['_PROTECTIONLINK']._serialized_start=530
  _globals['_PROTECTIONLINK']._serialized_end=642
  _globals['_CONDITION']._serialized_start=645
  _globals['_CONDITION']._serialized_end=1512
  _globals['_CONDITION_RELEASECHANNELSTABLECONDITION']._serialized_start=952
  _globals['_CONDITION_RELEASECHANNELSTABLECONDITION']._serialized_end=1178
  _globals['_CONDITION_MANUALAPPROVAL']._serialized_start=1180
  _globals['_CONDITION_MANUALAPPROVAL']._serialized_end=1232
  _globals['_CONDITION_CUSTOMTASKSUCCESSFULCONDITION']._serialized_start=1235
  _globals['_CONDITION_CUSTOMTASKSUCCESSFULCONDITION']._serialized_end=1499
  _globals['_CONDITION_CUSTOMTASKSUCCESSFULCONDITION_PROTECTION']._serialized_start=1398
  _globals['_CONDITION_CUSTOMTASKSUCCESSFULCONDITION_PROTECTION']._serialized_end=1489
  _globals['_DELIVERYEXTENSION']._serialized_start=1515
  _globals['_DELIVERYEXTENSION']._serialized_end=1675
  _globals['_PROTECTIONATTACHMENTDEFINITION']._serialized_start=1677
  _globals['_PROTECTIONATTACHMENTDEFINITION']._serialized_end=1783
  _globals['_IDENTIFIER']._serialized_start=1785
  _globals['_IDENTIFIER']._serialized_end=1861
  _globals['_CONCURRENCYLIMIT']._serialized_start=1863
  _globals['_CONCURRENCYLIMIT']._serialized_end=1899
  _globals['_METADATA']._serialized_start=1902
  _globals['_METADATA']._serialized_end=2691
  _globals['_STATUSEXPLANATION']._serialized_start=2694
  _globals['_STATUSEXPLANATION']._serialized_end=2867
  _globals['_ACTIONEXPLANATION']._serialized_start=2870
  _globals['_ACTIONEXPLANATION']._serialized_end=3009
  _globals['_VERSION']._serialized_start=3012
  _globals['_VERSION']._serialized_end=3234
  _globals['_SERVICEINSTANCESTATE']._serialized_start=3237
  _globals['_SERVICEINSTANCESTATE']._serialized_end=3725
  _globals['_SERVICESTATE']._serialized_start=3728
  _globals['_SERVICESTATE']._serialized_end=4197
  _globals['_SERVICEINSTANCELABELSELECTOR']._serialized_start=4200
  _globals['_SERVICEINSTANCELABELSELECTOR']._serialized_end=4525
  _globals['_SERVICEGROUPSTATE']._serialized_start=4528
  _globals['_SERVICEGROUPSTATE']._serialized_end=4821
  _globals['_CANARYPROGRESSSTATE']._serialized_start=4824
  _globals['_CANARYPROGRESSSTATE']._serialized_end=5120
  _globals['_CANARYPROGRESSSTATE_STATUS']._serialized_start=5059
  _globals['_CANARYPROGRESSSTATE_STATUS']._serialized_end=5120
  _globals['_BLUEGREENPROGRESSSTATE']._serialized_start=5123
  _globals['_BLUEGREENPROGRESSSTATE']._serialized_end=5342
  _globals['_BLUEGREENPROGRESSSTATE_STATUS']._serialized_start=5226
  _globals['_BLUEGREENPROGRESSSTATE_STATUS']._serialized_end=5342
  _globals['_DELIVERYSTATE']._serialized_start=5345
  _globals['_DELIVERYSTATE']._serialized_end=5832
  _globals['_DELIVERYSTATE_STATUS']._serialized_start=5671
  _globals['_DELIVERYSTATE_STATUS']._serialized_end=5784
  _globals['_FETCHDETAILS']._serialized_start=5835
  _globals['_FETCHDETAILS']._serialized_end=6304
  _globals['_FETCHDETAILS_FETCHSTATUS']._serialized_start=6238
  _globals['_FETCHDETAILS_FETCHSTATUS']._serialized_end=6304
  _globals['_RUNTIMEEXTENSIONFETCHOUTPUT']._serialized_start=6307
  _globals['_RUNTIMEEXTENSIONFETCHOUTPUT']._serialized_end=6706
  _globals['_RUNTIMEEXTENSIONGETINFOOUTPUTCONTENT']._serialized_start=6708
  _globals['_RUNTIMEEXTENSIONGETINFOOUTPUTCONTENT']._serialized_end=6777
  _globals['_RUNTIMEEXTENSIONGETINFODETAILS']._serialized_start=6780
  _globals['_RUNTIMEEXTENSIONGETINFODETAILS']._serialized_end=7186
  _globals['_RUNTIMEEXTENSIONGETINFODETAILS_STATUS']._serialized_start=7138
  _globals['_RUNTIMEEXTENSIONGETINFODETAILS_STATUS']._serialized_end=7186
  _globals['_RUNTIMEEXTENSIONGETINFOOUTPUT']._serialized_start=7188
  _globals['_RUNTIMEEXTENSIONGETINFOOUTPUT']._serialized_end=7307
  _globals['_APPLYDETAILS']._serialized_start=7310
  _globals['_APPLYDETAILS']._serialized_end=7668
  _globals['_APPLYDETAILS_APPLYSTATUS']._serialized_start=7600
  _globals['_APPLYDETAILS_APPLYSTATUS']._serialized_end=7668
  _globals['_RUNTIMEEXTENSIONAPPLYOUTPUT']._serialized_start=7671
  _globals['_RUNTIMEEXTENSIONAPPLYOUTPUT']._serialized_end=7831
  _globals['_RUNTIMEOBJECT']._serialized_start=7834
  _globals['_RUNTIMEOBJECT']._serialized_end=10399
  _globals['_RUNTIMEOBJECT_RUNTIMEEXTENSION']._serialized_start=9039
  _globals['_RUNTIMEOBJECT_RUNTIMEEXTENSION']._serialized_end=10206
  _globals['_RUNTIMEOBJECT_STATUS']._serialized_start=10208
  _globals['_RUNTIMEOBJECT_STATUS']._serialized_end=10256
  _globals['_RUNTIMEOBJECT_MANAGEMENTSTATUS']._serialized_start=10258
  _globals['_RUNTIMEOBJECT_MANAGEMENTSTATUS']._serialized_end=10308
  _globals['_CONDITIONSTATE']._serialized_start=10401
  _globals['_CONDITIONSTATE']._serialized_end=10480
  _globals['_APPLYERROR']._serialized_start=10482
  _globals['_APPLYERROR']._serialized_end=10511
  _globals['_NOTIFICATIONINFO']._serialized_start=10514
  _globals['_NOTIFICATIONINFO']._serialized_end=10867
  _globals['_CONTROLSTATE']._serialized_start=10870
  _globals['_CONTROLSTATE']._serialized_end=11574
  _globals['_MANUALAPPROVALSTATE']._serialized_start=11577
  _globals['_MANUALAPPROVALSTATE']._serialized_end=11756
  _globals['_STATE']._serialized_start=11759
  _globals['_STATE']._serialized_end=12464
  _globals['_ANNOTATIONS']._serialized_start=12467
  _globals['_ANNOTATIONS']._serialized_end=12597
  _globals['_ANNOTATIONS_ANNOTATION']._serialized_start=12557
  _globals['_ANNOTATIONS_ANNOTATION']._serialized_end=12597
  _globals['_CUSTOMTASKEXECUTIONSTATE']._serialized_start=12600
  _globals['_CUSTOMTASKEXECUTIONSTATE']._serialized_end=12774
  _globals['_CUSTOMTASKSTATE']._serialized_start=12777
  _globals['_CUSTOMTASKSTATE']._serialized_end=13239
  _globals['_PROTECTIONLINKSTATE']._serialized_start=13242
  _globals['_PROTECTIONLINKSTATE']._serialized_end=13961
  _globals['_PROTECTIONLINKSTATE_STOPREASON']._serialized_start=13800
  _globals['_PROTECTIONLINKSTATE_STOPREASON']._serialized_end=13961
  _globals['_PROTECTIONATTACHMENT']._serialized_start=13964
  _globals['_PROTECTIONATTACHMENT']._serialized_end=14485
  _globals['_DELIVERYEXTENSIONSTATE']._serialized_start=14488
  _globals['_DELIVERYEXTENSIONSTATE']._serialized_end=15098
  _globals['_SIGNAL']._serialized_start=15101
  _globals['_SIGNAL']._serialized_end=15657
  _globals['_SIGNAL_DELIVERYPROMOTIONCONFIG']._serialized_start=15444
  _globals['_SIGNAL_DELIVERYPROMOTIONCONFIG']._serialized_end=15514
  _globals['_SIGNAL_PROTECTIONBYPASS']._serialized_start=15516
  _globals['_SIGNAL_PROTECTIONBYPASS']._serialized_end=15534
  _globals['_SIGNAL_RUNTIMEEXTENSIONAPPROVAL']._serialized_start=15536
  _globals['_SIGNAL_RUNTIMEEXTENSIONAPPROVAL']._serialized_end=15647
  _globals['_DEBUGLOG']._serialized_start=15659
  _globals['_DEBUGLOG']._serialized_end=15722
  _globals['_RUNTIMEEXTENSIONMETADATA']._serialized_start=15725
  _globals['_RUNTIMEEXTENSIONMETADATA']._serialized_end=15858
  _globals['_MANUALAPPROVALCONFIG']._serialized_start=15860
  _globals['_MANUALAPPROVALCONFIG']._serialized_end=15977
  _globals['_MISSINGAPPROVAL']._serialized_start=15980
  _globals['_MISSINGAPPROVAL']._serialized_end=16201
  _globals['_CONCURRENCYLIMITEXCEEDED']._serialized_start=16204
  _globals['_CONCURRENCYLIMITEXCEEDED']._serialized_end=16382
  _globals['_APPLYCONDITIONUNSATISFIED']._serialized_start=16385
  _globals['_APPLYCONDITIONUNSATISFIED']._serialized_end=16877
  _globals['_APPLYCONDITIONUNSATISFIED_INTERNALMISSINGAPPROVAL']._serialized_start=16618
  _globals['_APPLYCONDITIONUNSATISFIED_INTERNALMISSINGAPPROVAL']._serialized_end=16867
  _globals['_FETCHTASKSTARTDETAILS']._serialized_start=16879
  _globals['_FETCHTASKSTARTDETAILS']._serialized_end=16963
  _globals['_CONCURRENCYLEASE']._serialized_start=16965
  _globals['_CONCURRENCYLEASE']._serialized_end=17019
  _globals['_TASKRUN']._serialized_start=17022
  _globals['_TASKRUN']._serialized_end=17934
  _globals['_TASKRUN_PHASE']._serialized_start=17897
  _globals['_TASKRUN_PHASE']._serialized_end=17934
  _globals['_TASKENTITYCONTEXT']._serialized_start=17937
  _globals['_TASKENTITYCONTEXT']._serialized_end=18153
  _globals['_SETDESIREDSTATEMETADATA']._serialized_start=18155
  _globals['_SETDESIREDSTATEMETADATA']._serialized_end=18244
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_extension/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.delivery_extension import config_pb2 as prodvana_dot_delivery__extension_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(prodvana/delivery_extension/object.proto\x12\x1bprodvana.delivery_extension\x1a\x1aprodvana/object/meta.proto\x1a(prodvana/delivery_extension/config.proto\"\xc8\x01\n\x11\x44\x65liveryExtension\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x44\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12\x42\n\x05state\x18\x03 \x01(\x0b\x32\x33.prodvana.delivery_extension.DeliveryExtensionState\"\x18\n\x16\x44\x65liveryExtensionStateBWZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.delivery_extension.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extension'
  _globals['_DELIVERYEXTENSION']._serialized_start=144
  _globals['_DELIVERYEXTENSION']._serialized_end=344
  _globals['_DELIVERYEXTENSIONSTATE']._serialized_start=346
  _globals['_DELIVERYEXTENSIONSTATE']._serialized_end=370
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/insights/insights.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/insights/insights.proto\x12\x11prodvana.insights\"\xba\x02\n\x07Insight\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\'\n\x05\x63lass\x18\x06 \x01(\x0e\x32\x18.prodvana.insights.Class\x12\x35\n\x07service\x18\x03 \x01(\x0b\x32\".prodvana.insights.Insight.SubjectH\x00\x12\x39\n\x0b\x61pplication\x18\x04 \x01(\x0b\x32\".prodvana.insights.Insight.SubjectH\x00\x12:\n\x0corganization\x18\x05 \x01(\x0b\x32\".prodvana.insights.Insight.SubjectH\x00\x1a#\n\x07Subject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\tB\x0f\n\rsubject_oneof*\xce\x01\n\x05\x43lass\x12\x0b\n\x07UNKNOWN\x10\x00\x12,\n(SUCCESSFUL_DEPLOYMENT_FREQUENCY_DECREASE\x10\x01\x12$\n DEPLOYMENT_FAILURE_RATE_INCREASE\x10\x02\x12\x32\n.MEDIAN_SUCCESSFUL_DEPLOYMENT_DURATION_INCREASE\x10\x03\x12\x30\n,MEDIAN_SUCCESSFUL_ROLLBACK_DURATION_INCREASE\x10\x04\x42MZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/insightsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.insights.insights_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/insights'
  _globals['_CLASS']._serialized_start=373
  _globals['_CLASS']._serialized_end=579
  _globals['_INSIGHT']._serialized_start=56
  _globals['_INSIGHT']._serialized_end=370
  _globals['_INSIGHT_SUBJECT']._serialized_start=318
  _globals['_INSIGHT_SUBJECT']._serialized_end=353
# @@protoc_insertion_point(module_scope)
